rse package — The Research Software Encyclopedia 11 documentation

# rse package

## Subpackages

- rse.app package
  - Subpackages
    - rse.app.views package
      - Submodules
      - rse.app.views.main module
      - rse.app.views.repositories module
      - Module contents
  - Submodules
  - rse.app.api module
  - rse.app.config module
  - rse.app.server module
  - Module contents
- rse.client package
  - Submodules
  - rse.client.add module
  - rse.client.clear module
  - rse.client.config module
  - rse.client.exists module
  - rse.client.export module
  - rse.client.generate module
  - rse.client.get module
  - rse.client.init module
  - rse.client.listing module
  - rse.client.search module
  - rse.client.shell module
  - rse.client.start module
  - rse.client.update module
  - Module contents
- rse.logger package
  - Submodules
  - rse.logger.message module
  - Module contents
- rse.main package
  - Subpackages
    - rse.main.config package
      - Module contents
    - rse.main.database package
      - Submodules
      - rse.main.database.base module
      - rse.main.database.filesystem module
      - rse.main.database.models module
      - rse.main.database.relational module
      - rse.main.database.sqlite module
      - Module contents
    - rse.main.parsers package
      - Submodules
      - rse.main.parsers.base module
      - rse.main.parsers.github module
      - Module contents
  - Submodules
  - rse.main.criteria module
  - rse.main.taxonomy module
  - Module contents
- rse.utils package
  - Submodules
  - rse.utils.command module
  - rse.utils.file module
  - rse.utils.prompt module
  - Module contents

## Submodules

## rse.defaults module

Copyright (C) 2020 Vanessa Sochat.

This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.

rse.defaults.getenv(variable_key, default=None, required=False, silent=True)

  attempt to get an environment variable. If the variable is not found, None is returned.

  Arguments:

  > - variable_key (str) : the variable name

  > - required (bool) : exit with error if not found

  > - silent (bool) : Do not print debugging information

## rse.exceptions module

Copyright (C) 2020 Vanessa Sochat.

This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.

exception rse.exceptions.DatabaseStringFormatError

  Bases: `RuntimeError`

  Thrown if database prefix is not supported

exception rse.exceptions.DirectoryNotFoundError(dirname, reason, *args, **kwargs)

  Bases: `FileNotFoundError`

  Thrown if a directory is not found

exception rse.exceptions.MissingDatabaseString(reason=None, *args, **kwargs)

  Bases: `RuntimeError`

  Thrown if a database string is required and not provided

exception rse.exceptions.MissingEnvironmentVariable(varname, *args, **kwargs)

  Bases: `RuntimeError`

  Thrown if a required environment variable is not provided.

exception rse.exceptions.MultipleReposExistError(uid, *args, **kwargs)

  Bases: `rse.exceptions.RepoError`

  Thrown if multiple repos exist.

exception rse.exceptions.NoReposError(*args, **kwargs)

  Bases: `rse.exceptions.RepoError`

  Thrown if repos are requested, but there are none

exception rse.exceptions.RepoError(uid=None, reason=None, *args, **kwargs)

  Bases: `RuntimeError`

  Abstract base class for any kind of RepoError.

exception rse.exceptions.RepoMetadataExistError(uid, key, *args, **kwargs)

  Bases: `rse.exceptions.RepoError`

  Thrown if a metadata value (label) already exists.

exception rse.exceptions.RepoNotFoundError(uid, *args, **kwargs)

  Bases: `rse.exceptions.RepoError`

  Thrown if a repo does not exist (for a remote)

## rse.version module

Copyright (C) 2020 Vanessa Sochat.

This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.

## Module contents

Copyright (C) 2020 Vanessa Sochat.

This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.